#!/bin/bash
#
# Copyright (C) 2019 OX Software GmbH
# 
# This file is part of OX Automation.
#
# OX Automation is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# OX Automation is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
# See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with OX Automation. If not, see <http://www.gnu.org/licenses/>.
#
#
# Authors:
# Benedikt Kroening <benedikt.kroening@open-xchange.com>
#
set -e
SCRIPT_DIR="$( cd "$(dirname "$0")" ; pwd -P)"
# sourcing some commonly used functions and executing basic checks
source ${SCRIPT_DIR}/../lib/common.bash
source ${SCRIPT_DIR}/../lib/setup.bash
checkRootPrivileges
detectDistribution

if [ -z ${JAVA_JDK_VERSION} ]; then
    JAVA_JDK_VERSION=8
fi


## Help text
show_usage() {
echo -n "
  $0 [OPTIONS]


"
}

### reading config from command line; overriding defaults
POSITIONAL=()
while [[ $# -gt 0 ]]
do
key="$1"

case $key in
    -h|--help)
    show_usage
    exit 0
    shift
    ;;
    --debug)
    echo "WARNING: Debug flag set (--debug)"
    set -x
    shift
    ;;

    # --repo-guard)
    # OX_REPO_GUARD="$2"
    # echo "WARNING: Using $OX_REPO_GUARD as guard repository source"
    # shift 
    # shift 
    # ;;
    *)    # unknown option
    POSITIONAL+=("$1") # save it in an array for later
    shift 
    ;;
esac
done
set -- "${POSITIONAL[@]}" # restore positional parameters

preInstallActions

PACKAGES=""

if [[ true == "${ANY_DEB}" ]]; then
    echo "Adding adoptopenjdk.jfrog.io build key to apt ..."
    wget -qO - https://adoptopenjdk.jfrog.io/adoptopenjdk/api/gpg/key/public | apt-key add -

    add-apt-repository --yes https://adoptopenjdk.jfrog.io/adoptopenjdk/deb/

    PACKAGES="adoptopenjdk-${JAVA_JDK_VERSION}-hotspot"
elif [[ true == "${ANY_RHEL}" ]]; then
    {
    echo "[AdoptOpenJDK]"
    echo "name=AdoptOpenJDK"
    echo "baseurl=http://adoptopenjdk.jfrog.io/adoptopenjdk/rpm/centos/7/$(uname -m)"
    echo "enabled=1"
    echo "gpgcheck=1"
    echo "gpgkey=https://adoptopenjdk.jfrog.io/adoptopenjdk/api/gpg/key/public"
            } > /etc/yum.repos.d/adoptopenjdk.repo


    PACKAGES="adoptopenjdk-${JAVA_JDK_VERSION}-hotspot"

elif [[ true == "${ANY_SLES}" ]]; then
    zypper ar -f http://adoptopenjdk.jfrog.io/adoptopenjdk/rpm/opensuse/15.0/$(uname -m) adoptopenjdk

    PACKAGES="adoptopenjdk-${JAVA_JDK_VERSION}-hotspot"
fi

# if ! [ -x "$(command -v java)" ]; then
#     echo "Adding nc package to list of packages ..."
#     PACKAGES="nc ${PACKAGES}"
# fi

installPackages ${PACKAGES}
